@@ -16,8 +16,9 @@ checkfail()
 # ARGUMENTS #
 #############
 
-MEDIALIBRARY_HASH=68558ef8
+MEDIALIBRARY_HASH=3ca56d9
 
+BUILD_ML=1
 RELEASE=0
 ASAN=0
 while [ $# -gt 0 ]; do
@@ -37,6 +38,9 @@ while [ $# -gt 0 ]; do
         --asan)
             ASAN=1
             ;;
+        --no-ml)
+            BUILD_ML=0
+            ;;
         release|--release)
             RELEASE=1
             ;;
@@ -408,13 +412,8 @@ NDK_LIB_DIR="${NDK_TOOLCHAIN_DIR}/${TARGET_TUPLE}/lib"
 if [ "${PLATFORM_SHORT_ARCH}" = "x86_64" -o "${PLATFORM_SHORT_ARCH}" = "mips64" ];then
     NDK_LIB_DIR="${NDK_LIB_DIR}64"
 fi
-NDK_LIB_UNWIND=""
-if [ "${ANDROID_ABI}" = "armeabi-v7a" ];then
-    NDK_LIB_DIR="${NDK_LIB_DIR}/armv7-a"
-    NDK_LIB_UNWIND="-lunwind"
-fi
 
-EXTRA_LDFLAGS="${EXTRA_LDFLAGS} -L${NDK_LIB_DIR} -lc++abi ${NDK_LIB_UNWIND}"
+EXTRA_LDFLAGS="${EXTRA_LDFLAGS} -L${NDK_LIB_DIR} -lc++abi -lc++_static"
 VLC_LDFLAGS="${EXTRA_LDFLAGS}"
 
 # Release or not?
@@ -706,49 +705,12 @@ if [ "${CHROME_OS}" != "1" ];then
     LIBANW_LIBS="$LIBANW_LIBS libanw.21"
 fi
 
-echo "Building NDK"
-
-if [ $ON_WINDOWS -eq 1 ]; then
-    OSCMD=.cmd
-fi
-
-$ANDROID_NDK/ndk-build$OSCMD -C libvlc \
-    APP_STL="c++_shared" \
-    LOCAL_CPP_FEATURES="rtti exceptions" \
-    VLC_SRC_DIR="$VLC_SRC_DIR" \
-    VLC_BUILD_DIR="$VLC_SRC_DIR/$VLC_BUILD_DIR" \
-    VLC_CONTRIB="$VLC_CONTRIB" \
-    VLC_CONTRIB_LDFLAGS="$VLC_CONTRIB_LDFLAGS" \
-    VLC_MODULES="$VLC_MODULES" \
-    VLC_LDFLAGS="$VLC_LDFLAGS" \
-    APP_BUILD_SCRIPT=jni/Android.mk \
-    APP_PLATFORM=android-${ANDROID_API} \
-    APP_ABI=${ANDROID_ABI} \
-    TARGET_TUPLE=$TARGET_TUPLE \
-    NDK_PROJECT_PATH=jni \
-    NDK_TOOLCHAIN_VERSION=clang \
-    NDK_DEBUG=${NDK_DEBUG}
-
-checkfail "ndk-build failed for libvlc"
-
-$ANDROID_NDK/ndk-build$OSCMD -C libvlc \
-    VLC_SRC_DIR="$VLC_SRC_DIR" \
-    ANDROID_SYS_HEADERS="$ANDROID_SYS_HEADERS" \
-    LIBIOMX_LIBS="$LIBIOMX_LIBS" \
-    LIBANW_LIBS="$LIBANW_LIBS" \
-    APP_BUILD_SCRIPT=private_libs/Android.mk \
-    APP_PLATFORM=android-${ANDROID_API} \
-    APP_ABI=${ANDROID_ABI} \
-    TARGET_TUPLE=$TARGET_TUPLE \
-    NDK_PROJECT_PATH=private_libs \
-    NDK_TOOLCHAIN_VERSION=clang
-
-checkfail "ndk-build failed for private libs"
-
 ################
 # MEDIALIBRARY #
 ################
 
+if [ ${BUILD_ML} = "1" ];then
+
 if [ ! -d "${SRC_DIR}/medialibrary" ]; then
     mkdir "${SRC_DIR}/medialibrary"
 fi
@@ -806,9 +768,8 @@ if [ ! -d "${MEDIALIBRARY_MODULE_DIR}/medialibrary" ]; then
     echo -e "\e[1m\e[32mmedialibrary source not found, cloning\e[0m"
     git clone http://code.videolan.org/videolan/medialibrary.git "${SRC_DIR}/medialibrary/medialibrary"
     checkfail "medialibrary source: git clone failed"
-    cd ${SRC_DIR}/medialibrary/medialibrary
+    cd ${MEDIALIBRARY_MODULE_DIR}/medialibrary
     git submodule update --init libvlcpp
-    cd -
 else
     cd ${MEDIALIBRARY_MODULE_DIR}/medialibrary
     if ! git cat-file -e ${MEDIALIBRARY_HASH}; then
@@ -816,9 +777,11 @@ else
       rm -rf ${MEDIALIBRARY_MODULE_DIR}/jni/libs
       rm -rf ${MEDIALIBRARY_MODULE_DIR}/jni/obj
     fi
-    cd ${SRC_DIR}
 fi
-
+if [ "$RELEASE" = 1 ]; then
+    git reset --hard ${MEDIALIBRARY_HASH}
+fi
+cd ${SRC_DIR}
 echo -e "\e[1m\e[36mCFLAGS:            ${CFLAGS}\e[0m"
 echo -e "\e[1m\e[36mEXTRA_CFLAGS:      ${EXTRA_CFLAGS}\e[0m"
 
@@ -881,30 +844,66 @@ checkfail "medialibrary: make failed"
 
 cd ${SRC_DIR}
 
-echo -e "ndk-build medialibrary"
-
-MEDIALIBRARY_LDLIBS="-L$SRC_DIR/libvlc/jni/libs/$ANDROID_ABI -lvlc \
--L${MEDIALIBRARY_BUILD_DIR}/build-android-$ANDROID_ABI/.libs -lmedialibrary \
+MEDIALIBRARY_LDLIBS="-L${MEDIALIBRARY_BUILD_DIR}/build-android-$ANDROID_ABI/.libs -lmedialibrary \
 -L$SRC_DIR/vlc/contrib/contrib-android-$TARGET_TUPLE/jpeg/.libs -ljpeg \
--L$MEDIALIBRARY_MODULE_DIR/$SQLITE_RELEASE/build-$ANDROID_ABI/.libs -lsqlite3 \
--L${NDK_LIB_DIR} -lc++abi ${NDK_LIB_UNWIND}"
+-L$MEDIALIBRARY_MODULE_DIR/$SQLITE_RELEASE/build-$ANDROID_ABI/.libs -lsqlite3"
 
-$ANDROID_NDK/ndk-build -C medialibrary \
-    APP_STL="c++_shared" \
-    ANDROID_SYS_HEADERS="$ANDROID_SYS_HEADERS" \
+if [ $ON_WINDOWS -eq 1 ]; then
+    OSCMD=.cmd
+fi
+
+###########
+# LINKING #
+###########
+
+fi # ${BUILD_ML} = "1"
+
+echo -e "ndk-build vlc"
+
+$ANDROID_NDK/ndk-build$OSCMD -C libvlc \
+    APP_STL="c++_static" \
+    APP_CPPFLAGS="-frtti -fexceptions" \
+    VLC_SRC_DIR="$VLC_SRC_DIR" \
+    VLC_BUILD_DIR="$VLC_SRC_DIR/$VLC_BUILD_DIR" \
+    VLC_CONTRIB="$VLC_CONTRIB" \
+    VLC_CONTRIB_LDFLAGS="$VLC_CONTRIB_LDFLAGS" \
+    VLC_MODULES="$VLC_MODULES" \
+    VLC_LDFLAGS="$VLC_LDFLAGS -latomic" \
+    MEDIALIBRARY_LDLIBS="${MEDIALIBRARY_LDLIBS}" \
+    MEDIALIBRARY_INCLUDE_DIR=${MEDIALIBRARY_BUILD_DIR}/include \
     APP_BUILD_SCRIPT=jni/Android.mk \
     APP_PLATFORM=android-${ANDROID_API} \
     APP_ABI=${ANDROID_ABI} \
-    LOCAL_CPP_FEATURES="rtti exceptions" \
-    TARGET_TUPLE=$TARGET_TUPLE \
     NDK_PROJECT_PATH=jni \
     NDK_TOOLCHAIN_VERSION=clang \
     NDK_DEBUG=${NDK_DEBUG} \
-    MEDIALIBRARY_LDLIBS="${MEDIALIBRARY_LDLIBS}" \
-    MEDIALIBRARY_INCLUDE_DIR=${MEDIALIBRARY_BUILD_DIR}/include
+    BUILD_ML=${BUILD_ML}
 
 checkfail "ndk-build failed"
 
+$ANDROID_NDK/ndk-build$OSCMD -C libvlc \
+    APP_BUILD_SCRIPT=jni/loader/Android.mk \
+    APP_PLATFORM=android-${ANDROID_API} \
+    APP_ABI=${ANDROID_ABI} \
+    NDK_PROJECT_PATH=jni/loader \
+    NDK_TOOLCHAIN_VERSION=clang
+
+checkfail "ndk-build failed for libvlc"
+
+$ANDROID_NDK/ndk-build$OSCMD -C libvlc \
+    VLC_SRC_DIR="$VLC_SRC_DIR" \
+    ANDROID_SYS_HEADERS="$ANDROID_SYS_HEADERS" \
+    LIBIOMX_LIBS="$LIBIOMX_LIBS" \
+    LIBANW_LIBS="$LIBANW_LIBS" \
+    APP_BUILD_SCRIPT=private_libs/Android.mk \
+    APP_PLATFORM=android-${ANDROID_API} \
+    APP_ABI=${ANDROID_ABI} \
+    TARGET_TUPLE=$TARGET_TUPLE \
+    NDK_PROJECT_PATH=private_libs \
+    NDK_TOOLCHAIN_VERSION=clang
+
+checkfail "ndk-build failed for private libs"
+
 echo "Dumping dbg symbols info ${OUT_DBG_DIR}"
 
 cd ${SRC_DIR}
@@ -913,4 +912,3 @@ OUT_DBG_DIR=.dbg/${ANDROID_ABI}
 mkdir -p $OUT_DBG_DIR
 cp -a libvlc/jni/obj/local/${ANDROID_ABI}/*.so ${OUT_DBG_DIR}
 cp -a libvlc/private_libs/obj/local/${ANDROID_ABI}/*.so ${OUT_DBG_DIR}
-cp -a medialibrary/jni/obj/local/${ANDROID_ABI}/*.so ${OUT_DBG_DIR}
