@@ -68,6 +68,9 @@ while [ $# -gt 0 ]; do
         --asan)
             ASAN=1
             ;;
+        --no-ml)
+            NO_ML=1
+            ;;
         *)
             diagnostic "$0: Invalid option '$1'."
             diagnostic "$0: Try --help for more information."
@@ -222,7 +225,7 @@ fi
 # Fetch VLC source #
 ####################
 
-TESTED_HASH=1c02164
+TESTED_HASH=8a3958c
 if [ ! -d "vlc" ]; then
     diagnostic "VLC source not found, cloning"
     git clone http://git.videolan.org/git/vlc.git vlc
@@ -259,6 +262,9 @@ fi
 if [ "$ASAN" = 1 ]; then
     OPTS="$OPTS --asan"
 fi
+if [ "$NO_ML" = 1 ]; then
+    OPTS="$OPTS --no-ml"
+fi
 
 ./compile-libvlc.sh $OPTS
 
