@@ -286,6 +286,8 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
     }
 
     public void browse(MediaWrapper media, int position, boolean save) {
+        if (!isResumed() || isRemoving())
+            return;
         mBrowserHandler.removeCallbacksAndMessages(null);
         final FragmentTransaction ft = getActivity().getSupportFragmentManager().beginTransaction();
         final Fragment next = createFragment();
@@ -709,7 +711,7 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
                     MediaLibraryItem item = currentMediaList.get(mCurrentParsedPosition);
                     item.setDescription(holderText);
                     final int position = mCurrentParsedPosition;
-                    VLCApplication.runOnMainThread(new Runnable() {
+                    mRecyclerView.post(new Runnable() {
                         @Override
                         public void run() {
                             mAdapter.notifyItemChanged(position, holderText);
