@@ -28,11 +28,11 @@ import android.content.Intent;
 import android.os.Build;
 import android.os.Bundle;
 import android.support.v7.preference.Preference;
+import android.widget.Toast;
 
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.SecondaryActivity;
-import org.videolan.vlc.gui.helpers.UiTools;
 
 @TargetApi(Build.VERSION_CODES.JELLY_BEAN_MR1)
 public class PreferencesFragment extends BasePreferenceFragment {
@@ -68,7 +68,7 @@ public class PreferencesFragment extends BasePreferenceFragment {
         switch (preference.getKey()){
             case "directories":
                 if (VLCApplication.getMLInstance().isWorking())
-                    UiTools.snacker(getView(), getString(R.string.settings_ml_block_scan));
+                    Toast.makeText(getContext(), getString(R.string.settings_ml_block_scan), Toast.LENGTH_SHORT).show();
                 else {
                     final Intent intent = new Intent(VLCApplication.getAppContext(), SecondaryActivity.class);
                     intent.putExtra("fragment", SecondaryActivity.STORAGE_BROWSER);
